@@ -20,25 +20,27 @@
 #include <koApplication.h>
 #include <koDocument.h>
 #include <koMainWindow.h>
+#include <koQueryTypes.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
-#include <dcopclient.h>
-#include "example_aboutdata.h"
+#include <kaboutdata.h>
+#include "example_factory.h"
+
 
 
 static const KCmdLineOptions options[]=
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
+	{"+[file]", I18N_NOOP("File To Open"),0},
+	{0,0,0}
 };
 
-extern "C" int kdemain( int argc, char **argv )
+int main( int argc, char **argv )
 {
-    KCmdLineArgs::init( argc, argv, newExampleAboutData() );
+    KCmdLineArgs::init( argc, argv, ExampleFactory::aboutData() );
     KCmdLineArgs::addCmdLineOptions( options );
     KoApplication app;
-
-    if (!app.start()) // parses command line args, create initial docs and shells
-	return 1;
-    return app.exec();
+    
+    app.start(); // parses command line args, create initial docs and shells
+    app.exec();
+    return 0;
 }
