@@ -1,6 +1,5 @@
 /* This file is part of the KDE project
    Copyright (C) 2000 David Faure <faure@kde.org>
-   Copyright (C) 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -14,36 +13,33 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #ifndef CSVEXPORT_H
 #define CSVEXPORT_H
 
 #include <qstring.h>
-#include <KoFilter.h>
+#include <qcstring.h>
+#include <qfile.h>
+#include <qobject.h>
 
-namespace KSpread
-{
-class Sheet;
-}
+#include <koFilter.h>
+#include <koTarStore.h>
 
-class CSVExport : public KoFilter 
-{
-  Q_OBJECT
 
-  public:
-  CSVExport(KoFilter * parent, const char * name, const QStringList &);
-  virtual ~CSVExport() {}
+class CSVExport : public KoFilter {
 
-  virtual KoFilter::ConversionStatus convert( const QCString & from, const QCString & to );
+    Q_OBJECT
 
-  private:
-  QString exportCSVCell( KSpread::Sheet const * const sheet, int col, int row, QChar const & textQuote, QChar delimiter );
-
-  private:
-  QString m_eol; ///< End of line (LF, CR or CRLF)  
+public:
+    CSVExport(KoFilter *parent, QString name);
+    virtual ~CSVExport() {}
+    /** do the filtering :) */
+    virtual const bool filter(const QCString &fileIn, const QCString &fileOut,
+                              const QCString &from, const QCString &to,
+                              const QString &config=QString::null);
 };
+#endif
 
-#endif // CSVEXPORT_H
