@@ -13,24 +13,32 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #ifndef ASCIIEXPORT_H
 #define ASCIIEXPORT_H
 
-#include <KoFilter.h>
+#include <qstring.h>
+#include <qcstring.h>
+#include <qfile.h>
+#include <qobject.h>
+
+#include <koFilter.h>
+#include <koTarStore.h>
+
+
+class ASCIIExport : public KoFilter {
 
-class ASCIIExport : public KoFilter
-{
     Q_OBJECT
 
 public:
-    ASCIIExport(KoFilter* parent, const char* name, const QStringList&);
+    ASCIIExport(KoFilter *parent, QString name);
     virtual ~ASCIIExport() {}
-
-    virtual KoFilter::ConversionStatus convert(const QCString& from, const QCString& to);
+    /** filtering :) */
+    virtual const bool filter(const QCString &fileIn, const QCString &fileOut,
+                              const QCString &from, const QCString &to,
+                              const QString &config=QString::null);
 };
-
 #endif // ASCIIEXPORT_H
