@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: kchartWizardSelectDataPage.cc,v 1.3 2000/04/21 06:34:20 wtrobin Exp $ */
 
 #include "kchartWizardSelectDataPage.h"
 
@@ -6,10 +6,7 @@
 #include <qlineedit.h>
 #include <kdebug.h>
 
-namespace KChart
-{
-
-KChartWizardSelectDataPage::KChartWizardSelectDataPage( QWidget* parent ) :
+kchartWizardSelectDataPage::kchartWizardSelectDataPage( QWidget* parent ) :
   QWidget( parent )
 {
   rangeED = new QLineEdit( this, "LineEdit_1" );
@@ -25,9 +22,7 @@ KChartWizardSelectDataPage::KChartWizardSelectDataPage( QWidget* parent ) :
   tmpQLabel->setGeometry( 10, 50, 360, 20 );
   tmpQLabel->setText( "you must select another rectangular area here." );
 
-  kdDebug(35001) << "send needNewData() signal here and update area field in KChartWizard" << endl;
+  kdDebug(35001) << "send needNewData() signal here and update area field in kchartWizard" << endl;
 
   setMinimumSize( 600, 300 );
 }
-
-}  //namespace KChart
