@@ -5,20 +5,16 @@
 
 class QLineEdit;
 
-namespace KChart
+class kchartWizardSelectDataPage : public QWidget
 {
-
-class KChartWizardSelectDataPage : public QWidget
-{
-friend class KChartWizard;
+friend class kchartWizard;
 
 public:
-  KChartWizardSelectDataPage( QWidget* parent );
+  kchartWizardSelectDataPage( QWidget* parent );
 
 private:
   QLineEdit* rangeED;
 };
 
-}  //namespace KChart
 
 #endif
