@@ -2,27 +2,24 @@
 #define _kchartWIZARDSETUPAXESPAGE_H
 
 #include <qwidget.h>
-#include <kcolorbutton.h>
-
-class QColor;
-class QLineEdit;
-class QSpinBox;
-class QPushButton;
-class QCheckBox;
-
-namespace KChart
-{
+#include <qstring.h>
+#include <qcheckbox.h>
+#include <qlineedit.h>
+#include <qspinbox.h>
+#include <qpushbutton.h>
+#include <kcolorbtn.h>
+#include <qcolor.h>
 
 class KChartPart;
 class kchartWidget;
 
-class KChartWizardSetupAxesPage : public QWidget
+class kchartWizardSetupAxesPage : public QWidget
 {
   Q_OBJECT
 
 public:
-  KChartWizardSetupAxesPage( QWidget* parent, KChartPart* chart );
-  ~KChartWizardSetupAxesPage();
+  kchartWizardSetupAxesPage( QWidget* parent, KChartPart* chart );
+  ~kchartWizardSetupAxesPage();
   bool chart3d;
 public slots:
       void apply();
@@ -36,16 +33,13 @@ protected:
 private:
   kchartWidget* preview;
   KChartPart* _chart;
-  QCheckBox* gridX;
-  QCheckBox* gridY;
+  QCheckBox* grid;
   QCheckBox* border;
   QLineEdit *y_interval;
   QLineEdit *y_max;
   QLineEdit *y_min;
   QLineEdit *ylabel_fmt;
-#if 0
   QLineEdit *ylabel2_fmt;
-#endif
   QSpinBox *angle;
   QSpinBox *depth;
   QSpinBox *barWidth;
@@ -59,6 +53,4 @@ private:
   QColor colorBorder;
 };
 
-}  //namespace KChart
-
 #endif
