@@ -5,21 +5,17 @@
 
 class QRadioButton;
 class QCheckBox;
-
-namespace KChart
-{
-
 class kchartWidget;
 class KChartPart;
-class KChartWizard;
+class kchartWizard;
 
-class KChartWizardSetupDataPage : public QWidget
+class kchartWizardSetupDataPage : public QWidget
 {
   Q_OBJECT 
 
 public:
-  KChartWizardSetupDataPage( QWidget* parent, KChartPart* chart );
-  ~KChartWizardSetupDataPage();
+  kchartWizardSetupDataPage( QWidget* parent, KChartPart* chart );
+  ~kchartWizardSetupDataPage();
   
 private slots:
   void dataInRowsClicked();
@@ -29,8 +25,7 @@ private slots:
 
 private:
   KChartPart* _chart;
-  KChartWizard* _parent;
-
+  kchartWizard* _parent;
   kchartWidget* preview;
   QRadioButton* datacol;
   QRadioButton* datarow;
@@ -38,6 +33,4 @@ private:
   QCheckBox* coldescript;
 };
 
-}  //namespace KChart
-
 #endif
