@@ -1,5 +1,5 @@
 /**
- * $Id: kchart_factory.h 508787 2006-02-12 18:28:12Z ingwa $
+ * $Id: kchart_factory.h,v 1.5 2000/05/06 20:53:34 hausmann Exp $
  *
  * Kalle Dalheimer <kalle@kde.org>
  */
@@ -7,16 +7,11 @@
 #ifndef KCHART_FACTORY_H
 #define KCHART_FACTORY_H
 
-
-#include <KoFactory.h>
-
+#include <koFactory.h>
 
 class KInstance;
 class KAboutData;
 
-namespace KChart
-{
-
 class KChartFactory : public KoFactory
 {
     Q_OBJECT
@@ -24,12 +19,7 @@ public:
     KChartFactory( QObject* parent = 0, const char* name = 0 );
     virtual ~KChartFactory();
 
-    virtual KParts::Part  *createPartObject( QWidget* = 0, 
-					     const char * = 0,
-					     QObject* parent = 0,
-					     const char* name = 0,
-					     const char* classname = "KoDocument",
-					     const QStringList &args = QStringList() );
+    virtual QObject* create( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
 
     static KInstance* global();
 
@@ -38,9 +28,6 @@ public:
 
 private:
     static KInstance* s_global;
-    static KAboutData *s_aboutData;
 };
 
-}  //namespace KChart
-
 #endif
