@@ -1,4 +1,6 @@
 /****************************************************************************
+** $Id: sheetdlg.h,v 1.6 1999/11/14 18:46:47 kalle Exp $
+**
 ** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
@@ -34,21 +36,19 @@ public:
   int rows();
   int usedCols();
   int usedRows();
-  void setUsedCols( int );
-  void setUsedRows( int );
- 
+  
   QString getX(int);
   QString getY(int);
   double getCell(int,int);
 
-  static const int TABLE_SIZE;
+  static const int TABLE_SIZE = 16;
   
 protected:
   virtual void resizeEvent( QResizeEvent *);
   
 private:
 
-   Sheet *t;
+  Sheet *t;
   QPushButton *cancel,*ok;
   void resizeHandle( QSize );
   QLabel *usedrowsLA, *usedcolsLA;
