@@ -1,12 +1,10 @@
 #ifndef KFORMULA_FACTORY_H
 #define KFORMULA_FACTORY_H
 
-#include <KoFactory.h>
-//#include <kaboutdata.h>
+#include <koFactory.h>
+#include <kaboutdata.h>
 
 class KInstance;
-class KInstance;
-class KAboutData;
 
 class KFormulaFactory : public KoFactory
 {
@@ -15,15 +13,15 @@ public:
     KFormulaFactory( QObject* parent = 0, const char* name = 0 );
     ~KFormulaFactory();
 
-    virtual KParts::Part *createPartObject( QWidget *parentWidget = 0, const char *widgetName = 0, QObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const QStringList &args = QStringList() );
+    virtual QObject* create( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
 
     static KInstance* global();
 
     static KAboutData* aboutData();
 
+
 private:
     static KInstance* s_global;
-    static KAboutData* s_aboutData;
 };
 
 #endif
