@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
 
@@ -21,16 +20,25 @@
 #ifndef confrectdia_h
 #define confrectdia_h
 
+#include <qdialog.h>
 #include <qframe.h>
-#include <qpen.h>
-#include <qbrush.h>
+
+#include "global.h"
+
+#ifndef max
+#define max(a,b) ((a)>(b)?(a):(b))
+#endif
 
 class QPainter;
 class QLabel;
-class KIntNumInput;
+class QLineEdit;
 class QGroupBox;
 class QPushButton;
 
+/******************************************************************/
+/* class RectPreview                                               */
+/******************************************************************/
+
 class RectPreview : public QFrame
 {
     Q_OBJECT
@@ -40,20 +48,20 @@ public:
     ~RectPreview() {}
 
     void setRnds( int _rx, int _ry )
-        { xRnd = _rx; yRnd = _ry; repaint( contentsRect(), true ); }
-    void setPenBrush( const QPen &_pen, const QBrush &_brush )
-        { pen = _pen; brush = _brush; repaint( true ); }
+    { xRnd = _rx; yRnd = _ry; repaint( true ); }
 
 protected:
     void drawContents( QPainter* );
 
     int xRnd, yRnd;
-    QPen pen;
-    QBrush brush;
 
 };
 
-class ConfRectDia : public QWidget
+/******************************************************************/
+/* class ConfRectDia                                              */
+/******************************************************************/
+
+class ConfRectDia : public QDialog
 {
     Q_OBJECT
 
@@ -62,29 +70,31 @@ public:
     ~ConfRectDia();
 
     void setRnds( int _rx, int _ry );
-    void setPenBrush( const QPen &_pen, const QBrush &_brush );
-    void resetConfigChangedValues();
 
-    int getRndX() const { return xRnd; }
-    int getRndY() const { return yRnd; }
-    int getRectangleConfigChange() const;
+    int getRndX()
+    { return xRnd; }
+    int getRndY()
+    { return yRnd; }
 
 protected:
-    bool m_bRndXChanged, m_bRndYChanged;
     QLabel *lRndX, *lRndY;
-    KIntNumInput *eRndX, *eRndY;
+    QLineEdit *eRndX, *eRndY;
+    QGroupBox *gSettings, *gPreview;
     RectPreview *rectPreview;
+    QPushButton *okBut, *applyBut, *cancelBut;
+
     int xRnd, yRnd;
-    int oldXRnd, oldYRnd;
 
 protected slots:
-    void rndXChanged( int );
-    void rndYChanged( int );
+    void rndXChanged( const QString & );
+    void rndYChanged( const QString & );
     void Apply() { emit confRectDiaOk(); }
-    void slotReset();
+
 signals:
     void confRectDiaOk();
 
 };
 
 #endif
+
+
