@@ -13,45 +13,59 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #ifndef GLOBAL_H
 #define GLOBAL_H
 
+#define KPRESENTER_VERSION "pre-Beta1"
+
+#include <qsize.h>
+
 #include <kiconloader.h>
-#include "KPrFactory.h"
 
-class KPrPage;
+#include "kpresenter_factory.h"
 
-#define KPBarIcon( x ) BarIcon( x, KPrFactory::global() )
+#define KPBarIcon( x ) BarIcon( x, KPresenterFactory::global() )
+
+// factors
+// #define MM_TO_POINT 2.83465
+// #define POINT_TO_MM 0.3527772388
+
+#define POINT_TO_MM( px ) ( ( float )px/2.83465 )
+#define MM_TO_POINT( mm ) ( int( ( float )mm*2.83465 ) )
+#define POINT_TO_INCH( px ) ( ( float )px/72.0 )
+#define INCH_TO_POINT( inch ) ( int( ( float )inch*72.0 ) )
+#define MM_TO_INCH( mm ) ( mm/25.4 )
+#define INCH_TO_MM( inch ) ( inch*25.4 )
 
 #define MAX_UNDO_REDO 100
+#define NUM_OBJ_TYPES 9
 
 // types
-enum AlignType {
-    AT_LEFT = 0,
-    AT_TOP,
-    AT_RIGHT,
-    AT_BOTTOM,
-    AT_HCENTER,
-    AT_VCENTER
-};
-
 enum BackType {
     BT_COLOR = 0,
     BT_PICTURE = 1,
-    BT_CLIPART = 2,
-    BT_BRUSH = 3
+    BT_CLIPART = 2
 };
-
 enum BackView {
     BV_ZOOM = 0,
     BV_CENTER = 1,
     BV_TILED = 2
 };
-
+enum BCType {
+    BCT_PLAIN = 0,
+    BCT_GHORZ = 1,
+    BCT_GVERT = 2,
+    BCT_GDIAGONAL1 = 3,
+    BCT_GDIAGONAL2 = 4,
+    BCT_GCIRCLE = 5,
+    BCT_GRECT = 6,
+    BCT_GPIPECROSS = 7,
+    BCT_GPYRAMID = 8
+};
 enum ObjType {
     OT_PICTURE = 0,
     OT_LINE = 1,
@@ -63,19 +77,7 @@ enum ObjType {
     OT_UNDEFINED = 7,
     OT_PIE = 8,
     OT_PART = 9,
-    OT_GROUP = 10,
-    OT_FREEHAND = 11,
-    OT_POLYLINE = 12,
-    OT_QUADRICBEZIERCURVE = 13,
-    OT_CUBICBEZIERCURVE = 14,
-    OT_POLYGON = 15,
-    OT_CLOSED_LINE = 16
-};
-enum SelectionMode {
-    SM_NONE = 0,
-    SM_MOVERESIZE = 1,
-    SM_ROTATE = 2,
-    SM_PROTECT = 3
+    OT_GROUP = 10
 };
 enum LineType {
     LT_HORZ = 0,
@@ -146,75 +148,13 @@ enum PageEffect {
     PEF_INTERLOCKING_VERT_1 = 9,
     PEF_INTERLOCKING_VERT_2 = 10,
     PEF_SURROUND1 = 11,
-    PEF_FLY1 = 12,
-    PEF_BLINDS_HOR = 13,
-    PEF_BLINDS_VER = 14,
-    PEF_BOX_IN = 15,
-    PEF_BOX_OUT = 16,
-    PEF_CHECKBOARD_ACROSS = 17,
-    PEF_CHECKBOARD_DOWN = 18,
-    PEF_COVER_DOWN = 19,
-    PEF_UNCOVER_DOWN = 20,
-    PEF_COVER_UP = 21,
-    PEF_UNCOVER_UP = 22,
-    PEF_COVER_LEFT = 23,
-    PEF_UNCOVER_LEFT = 24,
-    PEF_COVER_RIGHT = 25,
-    PEF_UNCOVER_RIGHT = 26,
-    PEF_COVER_LEFT_UP = 27,
-    PEF_UNCOVER_LEFT_UP = 28,
-    PEF_COVER_LEFT_DOWN = 29,
-    PEF_UNCOVER_LEFT_DOWN = 30,
-    PEF_COVER_RIGHT_UP = 31,
-    PEF_UNCOVER_RIGHT_UP = 32,
-    PEF_COVER_RIGHT_DOWN = 33,
-    PEF_UNCOVER_RIGHT_DOWN = 34,
-    PEF_DISSOLVE = 35,
-    PEF_STRIPS_LEFT_UP = 36,
-    PEF_STRIPS_LEFT_DOWN = 37,
-    PEF_STRIPS_RIGHT_UP = 38,
-    PEF_STRIPS_RIGHT_DOWN = 39,
-    PEF_MELTING = 40,
-    PEF_LAST_MARKER = 41, // only marker, don't use this !
-    PEF_RANDOM = -1
+    PEF_FLY1 = 12
 };
-
-enum ImageEffect {
-    IE_NONE = -1,
-    IE_CHANNEL_INTENSITY = 0,
-    IE_FADE = 1,
-    IE_FLATTEN = 2,
-    IE_INTENSITY = 3,
-    IE_DESATURATE = 4,
-    IE_CONTRAST = 5,
-    IE_NORMALIZE = 6,
-    IE_EQUALIZE = 7,
-    IE_THRESHOLD = 8,
-    IE_SOLARIZE = 9,
-    IE_EMBOSS = 10,
-    IE_DESPECKLE = 11,
-    IE_CHARCOAL = 12,
-    IE_NOISE = 13,
-    IE_BLUR = 14,
-    IE_EDGE = 15,
-    IE_IMPLODE = 16,
-    IE_OIL_PAINT = 17,
-    IE_SHARPEN = 18,
-    IE_SPREAD = 19,
-    IE_SHADE = 20,
-    IE_SWIRL = 21,
-    IE_WAVE = 22
-};
-
 enum LineEnd {
     L_NORMAL = 0,
     L_ARROW,
     L_SQUARE,
-    L_CIRCLE,
-    L_LINE_ARROW,
-    L_DIMENSION_LINE,
-    L_DOUBLE_ARROW,
-    L_DOUBLE_LINE_ARROW
+    L_CIRCLE
 };
 enum ShadowDirection {
     SD_LEFT_UP = 1,
@@ -226,15 +166,26 @@ enum ShadowDirection {
     SD_LEFT_BOTTOM = 7,
     SD_LEFT = 8
 };
-
-typedef int PresSpeed;
-
-enum EffectSpeed {
-  ES_SLOW = 0,
-  ES_MEDIUM = 1,
-  ES_FAST = 2
+enum FillType
+{
+    FT_BRUSH = 0,
+    FT_GRADIENT = 1
+};
+enum PresSpeed {
+    PS_SLOW = 0,
+    PS_NORMAL = 1,
+    PS_FAST = 2
+};
+enum DelPageMode {
+    DPM_LET_OBJS = 0,
+    DPM_MOVE_OBJS = 1,
+    DPM_DEL_OBJS = 2,
+    DPM_DEL_MOVE_OBJS = 3
+};
+enum InsPageMode {
+    IPM_LET_OBJS = 0,
+    IPM_MOVE_OBJS = 1
 };
-
 enum InsertPos {
     IP_BEFORE = 0,
     IP_AFTER = 1
@@ -255,45 +206,22 @@ enum ToolEditMode {
     INS_DIAGRAMM = 7,
     INS_TABLE = 8,
     INS_FORMULA = 9,
-    INS_AUTOFORM = 10,
-    INS_FREEHAND = 11,
-    INS_POLYLINE = 12,
-    INS_QUADRICBEZIERCURVE = 13,
-    INS_CUBICBEZIERCURVE = 14,
-    INS_POLYGON = 15,
-    INS_PICTURE = 16,
-    INS_CLIPART = 17,
-    TEM_ROTATE = 18,
-    TEM_ZOOM = 19,
-    INS_CLOSED_FREEHAND = 20,
-    INS_CLOSED_POLYLINE = 21,
-    INS_CLOSED_QUADRICBEZIERCURVE = 22,
-    INS_CLOSED_CUBICBEZIERCURVE = 23
+    INS_AUTOFORM = 10
 };
-
-enum PictureMirrorType {
-    PM_NORMAL = 0,
-    PM_HORIZONTAL = 1,
-    PM_VERTICAL = 2,
-    PM_HORIZONTALANDVERTICAL = 3
-};
-
-enum PropValue {
-    STATE_ON = 0,
-    STATE_OFF = 1,
-    STATE_UNDEF = 2
-};
-
-enum VerticalAlignmentType {
-    KP_CENTER=0,
-    KP_TOP=1,
-    KP_BOTTOM=2
+enum PresentSlides {
+    PS_ALL = 0,
+    PS_CURRENT = 1,
+    PS_SELECTED = 2
 };
 
+static const float ObjSpeed[] = { 70.0, 50.0, 30.0 };
+static const float PageSpeed[] = { 8.0, 16.0, 32.0 };
 
 // offsets of the effects in the Effect2 enum accoording to a objType
 const int TxtObjOffset = 0;
 
-typedef QMap<QString, QValueList<KPrPage *> > CustomSlideShowMap;
+const QSize orig_size( -1, -1 );
+
+#undef SHOW_INFO
 
 #endif //GLOBAL_H
