@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
 
@@ -21,33 +20,43 @@
 #ifndef gotopage_h
 #define gotopage_h
 
-#include <kdialogbase.h>
+#include <qframe.h>
 #include <qvaluelist.h>
 
 class QWidget;
 class QObject;
+class QEvent;
 class QResizeEvent;
-class QListBox;
-class KPresenterDoc;
+class QComboBox;
+class QLabel;
 
-class KPGotoPage : public KDialogBase
+/******************************************************************/
+/* class KPGotoPage                                               */
+/******************************************************************/
+
+class KPGotoPage : public QFrame
 {
+    Q_OBJECT
+
 public:
-    KPGotoPage( const KPresenterDoc *doc,
-                const QValueList<int> &slides, int start,
-                QWidget *parent = 0L, const char *name = 0L );
+    KPGotoPage( const QValueList<int> &slides, int start,
+                QWidget *parent = 0L, const char *name = 0L, WFlags f = 0 );
 
-    static int gotoPage( const KPresenterDoc *doc,
-                         const QValueList<int> &slides, int start,
-                         QWidget *parent = 0L );
+    bool eventFilter( QObject *obj, QEvent *e );
 
-    int page() const;
+    int getPage() { return page; }
 
-private:
-    void resetCursor();
+    static int gotoPage( const QValueList<int> &slides, int start, QWidget *parent = 0L );
+
+protected:
+    void resizeEvent( QResizeEvent *e );
+
+    QComboBox *spinbox;
+    QLabel *label;
+
+    int _default, page;
 
-    QListBox *spinbox;
-    int oldPage;
 };
 
+
 #endif
