@@ -30,7 +30,7 @@ public:
     KPresenterFactory( QObject* parent = 0, const char* name = 0 );
     ~KPresenterFactory();
 
-    virtual KParts::Part *createPartObject( QWidget *parentWidget = 0, const char *widgetName = 0, QObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const QStringList &args = QStringList() );
+    virtual QObject* create( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
 
     static KInstance* global();
 
@@ -39,7 +39,6 @@ public:
 
 private:
     static KInstance* s_global;
-    static KAboutData* s_aboutData;
 };
 
 #endif
