@@ -17,32 +17,42 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include "kpresenter_aboutdata.h"
+#include "kpresenter_doc.h"
+#include "kpresenter_shell.h"
 
 #include <koApplication.h>
 
 #include <dcopclient.h>
+#include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 
 
 static const KCmdLineOptions options[]=
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
+	{"+[file]", I18N_NOOP("File To Open"),0},
+	{0,0,0}
 };
 
+extern "C"
+{
+    void* init_libkpresenter();
+}
+
 int main( int argc, char **argv )
 {
-    KCmdLineArgs::init( argc, argv, newKPresenterAboutData() );
+    KCmdLineArgs::init( argc, argv, KPresenterFactory::aboutData());
     KCmdLineArgs::addCmdLineOptions( options );
-
-    KoApplication app;
+       
+    KoApplication app; 
+    init_libkpresenter();
+	
     app.dcopClient()->attach();
     app.dcopClient()->registerAs( "kpresenter" );
 
-    if (!app.start())
-        return 1;
+    app.start();
 
-    return app.exec();
+    app.exec();
+
+    return 0;
 }
