@@ -1,7 +1,5 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
-   Copyright (C) 2002, 2003 Ariya Hidayat <ariya@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,67 +20,65 @@
 #ifndef PGCONFDIA_H
 #define PGCONFDIA_H
 
+#include <qdialog.h>
+#include <qmap.h>
+
 #include "global.h"
 
-#include <qmap.h>
-#include <qpen.h>
-#include <qvaluelist.h>
-
-#include <kdialogbase.h>
-
-class KPresenterDoc;
-
-class QCheckBox;
-class QComboBox;
-class QColor;
+class QButtonGroup;
+class QLabel;
+class QPushButton;
+class QVBox;
+class QResizeEvent;
 class QListView;
+class KPresenterDoc;
 class QRadioButton;
+class QComboBox;
+class QCheckBox;
 
-class KIntNumInput;
-class KColorButton;
-class QSlider;
+/******************************************************************/
+/* class PgConfDia                                                */
+/******************************************************************/
 
-class PgConfDia : public KDialogBase
+class PgConfDia : public QDialog
 {
     Q_OBJECT
 
 public:
 
     // constructor - destructor
-    PgConfDia( QWidget* parent, KPresenterDoc* doc );
-    ~PgConfDia();
-    bool getInfiniteLoop() const;
-    bool getManualSwitch() const;
-    bool getPresentationDuration() const;
-    QPen getPen() const;
-    QValueList<bool> getSelectedSlides() const;
-
-    QString presentationName() const;
+    PgConfDia( QWidget* parent, KPresenterDoc *doc, const char* name,
+               bool infLoop, bool swMan, int pgNum,
+               PageEffect pageEffect, PresSpeed presSpeed,
+               PresentSlides presSlides, const QMap<int,bool> &selectedSlides );
+    bool getInfinitLoop();
+    bool getManualSwitch();
+    PageEffect getPageEffect();
+    PresSpeed getPresSpeed();
+    PresentSlides getPresentSlides();
+    QMap<int,bool> getSelectedSlides();
 
 protected:
+    void resizeEvent( QResizeEvent *e );
 
-    KPresenterDoc* m_doc;
-
-    QCheckBox *infiniteLoop, *presentationDuration;
-    QRadioButton *m_manualButton, *m_autoButton;
-    KColorButton* penColor;
-    KIntNumInput* penWidth;
-    QComboBox *m_customSlideCombobox;
-    QListView *slides;
-    QRadioButton *m_customSlide, *m_selectedSlide;
-    void setupPageGeneral();
-    void setupPageSlides();
+    QButtonGroup *general, *page, *slides;
+    QCheckBox *infinitLoop, *manualSwitch;
+    QRadioButton *slidesAll, *slidesCurrent, *slidesSelected;
+    QLabel *label1, *label2, *label3, *label4;
+    QPushButton *cancelBut, *okBut;
+    QComboBox *effectCombo, *speedCombo;
+    QVBox *back;
+    QListView *lSlides;
 
 public slots:
     void confDiaOk() { emit pgConfDiaOk(); }
 
+protected slots:
+    void presSlidesChanged( int );
+
 signals:
     void pgConfDiaOk();
 
-protected slots:
-    void selectAllSlides();
-    void deselectAllSlides();
-    void radioButtonClicked();
 };
 
 #endif
