@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
 
@@ -21,105 +20,103 @@
 #ifndef webpresentation_h
 #define webpresentation_h
 
-#include <kwizard.h>
-
+#include <qstring.h>
+#include <qstringlist.h>
+#include <qcolor.h>
+#include <qwizard.h>
 #include <qdialog.h>
-#include <qvaluelist.h>
-
 
 class KPresenterDoc;
 class KPresenterView;
+class Page;
 
-class KURLRequester;
 class KColorButton;
-class KListView;
-class KIntNumInput;
-class KLineEdit;
-class KComboBox;
 
 class QVBox;
 class QHBox;
-
+class QLineEdit;
+class QSpinBox;
+class QComboBox;
+class QListView;
 class QListViewItem;
 class QCloseEvent;
 class KProgress;
 class QLabel;
 
-class QCheckBox;
+/******************************************************************/
+/* Class: KPWebPresentation                                       */
+/******************************************************************/
 
 class KPWebPresentation
 {
 public:
+    enum ImageFormat {BMP = 0, PNG, JPEG};
+
+    static QString imageFormat( ImageFormat i ) {
+        if ( i == BMP ) return QString( "bmp" );
+        if ( i == PNG ) return QString( "png" );
+        if ( i == JPEG ) return QString( "jpeg" );
+        return QString::null;
+    }
 
     KPWebPresentation( KPresenterDoc *_doc, KPresenterView *_view );
     KPWebPresentation( const QString &_config, KPresenterDoc *_doc, KPresenterView *_view );
     KPWebPresentation( const KPWebPresentation &webPres );
 
     void setAuthor( const QString &_author )
-        { author = _author; }
+    { author = _author; }
     void setEMail( const QString &_email )
-        { email = _email; }
+    { email = _email; }
     void setTitle( const QString &_title )
-        { title = _title; }
+    { title = _title; }
+    void setSlideTitles( const QStringList &_slideTitles )
+    { slideTitles = _slideTitles; }
     void setBackColor( const QColor &_backColor )
-        { backColor = _backColor; }
+    { backColor = _backColor; }
     void setTitleColor( const QColor &_titleColor )
-        { titleColor = _titleColor; }
+    { titleColor = _titleColor; }
     void setTextColor( const QColor &_textColor )
-        { textColor = _textColor; }
-    void setXML( bool _xml )
-        { xml = _xml; }
-    void setWriteHeader( bool _writeHeader )
-        { m_bWriteHeader = _writeHeader; }
-    void setWriteFooter( bool _writeFooter )
-        { m_bWriteFooter = _writeFooter; }
-    void setLoopSlides( bool _loopSlides )
-        { m_bLoopSlides = _loopSlides; }
+    { textColor = _textColor; }
+    void setImageFormat( ImageFormat _imgFormat )
+    { imgFormat = _imgFormat; }
     void setPath( const QString &_path )
-        { path = _path; }
+    { path = _path; }
     void setZoom( int _zoom )
-        { zoom = _zoom; }
-    void setTimeBetweenSlides( int _timeBetweenSlides )
-        { timeBetweenSlides = _timeBetweenSlides; } // PAU
-    void setEncoding( const QString &_encoding ) { m_encoding = _encoding; }
+    { zoom = _zoom; }
 
-    QString getAuthor() const { return author; }
-    QString getEmail() const { return email; }
-    QString getTitle() const { return title; }
-    QColor getBackColor() const { return backColor; }
-    QColor getTitleColor() const { return titleColor; }
-    QColor getTextColor() const { return textColor; }
-    bool isXML() const { return xml; }
-    bool wantHeader() const { return m_bWriteHeader; }
-    bool wantFooter() const { return m_bWriteFooter; }
-    bool wantLoopSlides() const { return m_bLoopSlides; }
-    QString getPath() const { return path; }
-    int getZoom() const { return zoom; }
-    int getTimeBetweenSlides() const { return timeBetweenSlides; } // PAU
-    QString getEncoding() const { return m_encoding; }
-
-    struct SlideInfo {
-        int pageNumber; /* 0-based */
-        QString slideTitle;
-    };
-    // Each entry in this list is a page (number+title).
-    // This allows to skip pages.
-    QValueList<SlideInfo> getSlideInfos() const { return slideInfos; }
-
-    void setSlideTitle( int i, const QString &slideTitle )
-        { slideInfos[i].slideTitle = slideTitle; }
+    QString getAuthor()
+    { return author; }
+    QString getEmail()
+    { return email; }
+    QString getTitle()
+    { return title; }
+    QStringList &getSlideTitles()
+    { return slideTitles; }
+    QColor getBackColor()
+    { return backColor; }
+    QColor getTitleColor()
+    { return titleColor; }
+    QColor getTextColor()
+    { return textColor; }
+    ImageFormat getImageFormat()
+    { return imgFormat; }
+    QString getPath()
+    { return path; }
+    int getZoom()
+    { return zoom; }
 
     void setConfig( const QString &_config )
-        { config = _config; }
-    QString getConfig() const { return config; }
+    { config = _config; }
+    QString getConfig()
+    { return config; }
 
     void loadConfig();
     void saveConfig();
 
-    int initSteps() const { return 7; }
-    int slides1Steps() { return slideInfos.count(); }
-    int slides2Steps() { return slideInfos.count(); }
-    int mainSteps() const { return 1; }
+    int initSteps() { return 7; }
+    int slides1Steps() { return slideTitles.count(); }
+    int slides2Steps() { return slideTitles.count(); }
+    int mainSteps() { return 1; }
 
     void initCreation( KProgress *progressBar );
     void createSlidesPictures( KProgress *progressBar );
@@ -128,25 +125,25 @@ public:
 
 protected:
     void init();
-    QString escapeHtmlText( QTextCodec *codec, const QString& strText ) const;
-    void writeStartOfHeader(QTextStream& streamOut, QTextCodec *codec,
-                            const QString& subtitle, const QString& dest, const QString& next);
 
     KPresenterDoc *doc;
     KPresenterView *view;
     QString config;
+
     QString author, title, email;
-    QValueList<SlideInfo> slideInfos;
+    QStringList slideTitles;
     QColor backColor, titleColor, textColor;
-    QString path;    
-    bool xml;
-    bool m_bWriteHeader, m_bWriteFooter, m_bLoopSlides;
-    int timeBetweenSlides;
+    QString path;
+    ImageFormat imgFormat;
     int zoom;
-    QString m_encoding;
+
 };
 
-class KPWebPresentationWizard : public KWizard
+/******************************************************************/
+/* Class: KPWebPresentationWizard                                 */
+/******************************************************************/
+
+class KPWebPresentationWizard : public QWizard
 {
     Q_OBJECT
 
@@ -157,12 +154,11 @@ public:
     static void createWebPresentation( const QString &_config, KPresenterDoc *_doc, KPresenterView *_view );
 
 protected:
-
     void setupPage1();
     void setupPage2();
     void setupPage3();
-    void setupPage4();
-    void setupPage5(); // PAU
+
+    bool isPathValid();
 
     void closeEvent( QCloseEvent *e );
 
@@ -171,25 +167,28 @@ protected:
     KPresenterView *view;
     KPWebPresentation webPres;
 
-    QHBox *page1, *page2, *page3, *page4, *page5; // PAU
-    QCheckBox *writeHeader, *writeFooter, *loopSlides; // PAU
-    KLineEdit *author, *title, *email;
+    QHBox *page1, *page2, *page3;
+    QLineEdit *author, *title, *email, *path;
     KColorButton *textColor, *titleColor, *backColor;
-    KComboBox *encoding, *doctype;
-    KIntNumInput *zoom, *timeBetweenSlides; // PAU
-    KURLRequester *path;
-    KListView *slideTitles;
-    KLineEdit *slideTitle;
+    QComboBox *format;
+    QSpinBox *zoom;
+    QPushButton *choosePath;
+    QListView *slideTitles;
+    QLineEdit *slideTitle;
 
 protected slots:
     virtual void finish();
+    void slotChoosePath();
     void pageChanged();
-    void slotChoosePath(const QString &);
     void slideTitleChanged( const QString & );
     void slideTitleChanged( QListViewItem * );
 
 };
 
+/******************************************************************/
+/* Class: KPWebPresentationCreateDialog                           */
+/******************************************************************/
+
 class KPWebPresentationCreateDialog : public QDialog
 {
     Q_OBJECT
@@ -216,7 +215,7 @@ protected:
     KPWebPresentation webPres;
 
     KProgress *progressBar;
-    QLabel *step1, *step2, *step3, *step4, *step5;    
+    QLabel *step1, *step2, *step3, *step4;
     QPushButton *bDone, *bSave;
     QVBox *back;
 
@@ -225,3 +224,4 @@ protected slots:
 
 };
 #endif
+
