@@ -17,99 +17,84 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <assert.h>
+#include <qprinter.h>
 
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
+#include "kspread_dlg_cons.h"
+#include "kspread_view.h"
+#include "kspread_canvas.h"
+#include "kspread_doc.h"
+#include "kspread_util.h"
+#include "kspread_table.h"
 
-#include <kdebug.h>
-#include <kdialogbase.h>
+#include <kapp.h>
+#include <klocale.h>
 #include <kmessagebox.h>
 
-#include <koscript.h>
-
-#include <kspread_dlg_cons.h>
-#include <kspread_canvas.h>
-#include <kspread_doc.h>
-#include <kspread_global.h>
-#include <kspread_interpreter.h>
-#include <kspread_sheet.h>
-#include <kspread_util.h>
+#include <list>
+#include <cassert>
 
+#include <kdebug.h>
 
 KSpreadConsolidate::KSpreadConsolidate( KSpreadView* parent, const char* name )
-	: KDialogBase( parent, name, false, i18n("Consolidate"), Ok|Cancel )
+	: QDialog( parent, name )
 {
   m_pView = parent;
 
-  QWidget* page = new QWidget( this );
-  setMainWidget( page );
-
-  QGridLayout *grid1 = new QGridLayout( page, 12, 2, marginHint(), spacingHint() );
+  setCaption( i18n("Consolidate") );
 
   QLabel* tmpQLabel;
-  tmpQLabel = new QLabel( page, "Label_1" );
-  grid1->addWidget(tmpQLabel,0,0);
-  tmpQLabel->setText( i18n("&Function:") );
+  tmpQLabel = new QLabel( this, "Label_1" );
+  tmpQLabel->setGeometry( 10, 20, 150, 20 );
+  tmpQLabel->setText( i18n("Function") );
 
-  m_pFunction = new QComboBox( page );
-  grid1->addWidget(m_pFunction,1,0);
-  tmpQLabel->setBuddy(m_pFunction);
+  m_pFunction = new QComboBox( this );
+  m_pFunction->setGeometry( 10, 40, 150, 30 );
+  m_idSumme = 0; m_pFunction->insertItem( i18n("sum"), m_idSumme );
+  m_idAverage = 1; m_pFunction->insertItem( i18n("average"), m_idAverage );
 
-  m_pFunction->insertItem( i18n("Sum"), Sum );
-  m_pFunction->insertItem( i18n("Average"), Average );
-  m_pFunction->insertItem( i18n("Count"), Count );
-  m_pFunction->insertItem( i18n("Max"), Max );
-  m_pFunction->insertItem( i18n("Min"), Min );
-  m_pFunction->insertItem( i18n("Product"), Product );
-  m_pFunction->insertItem( i18n("Standard Deviation"), StdDev );
-  m_pFunction->insertItem( i18n("Variance"), Var );
+  tmpQLabel = new QLabel( this, "Label_1" );
+  tmpQLabel->setGeometry( 10, 80, 150, 30 );
+  tmpQLabel->setText( i18n("Reference") );
 
-  tmpQLabel = new QLabel( page, "Label_1" );
-  tmpQLabel->setText( i18n("Re&ference:") );
-  grid1->addWidget(tmpQLabel,2,0);
+  m_pRef = new QLineEdit( this );
+  m_pRef->setGeometry( 10, 110, 150, 30 );
 
-  m_pRef = new QLineEdit( page );
-  grid1->addWidget(m_pRef,3,0);
-  tmpQLabel->setBuddy(m_pRef);
+  tmpQLabel = new QLabel( this, "Label_1" );
+  tmpQLabel->setGeometry( 10, 140, 150, 30 );
+  tmpQLabel->setText( i18n("Entered References") );
 
-  tmpQLabel = new QLabel( page, "Label_1" );
-  grid1->addWidget(tmpQLabel,4,0);
-  tmpQLabel->setText( i18n("&Entered references:") );
+  m_pRefs = new QListBox( this );
+  m_pRefs->setGeometry( 10, 170, 150, 80 );
 
-  m_pRefs = new QListBox( page );
-  grid1->addMultiCellWidget( m_pRefs,5,8,0,0);
-  tmpQLabel->setBuddy(m_pRefs);
+  m_pOk = new QPushButton( i18n("Ok"), this );
+  m_pOk->setGeometry( 180, 20, 100, 30 );
+  m_pOk->setEnabled( false );
+  m_pClose = new QPushButton( i18n("Cancel"), this );
+  m_pClose->setGeometry( 180, 60, 100, 30 );
 
-  m_pRow = new QCheckBox( i18n("&Description in row"), page );
-  grid1->addWidget( m_pRow,9,0);
-  m_pCol = new QCheckBox( i18n("De&scription in column"), page );
-  grid1->addWidget(m_pCol,10,0);
-  m_pCopy = new QCheckBox( i18n("Co&py data"), page );
-  grid1->addWidget(m_pCopy,11,0);
-
-  m_pAdd = new QPushButton( i18n("&Add"), page );
-  grid1->addWidget(m_pAdd,2,1);
-  m_pRemove = new QPushButton( i18n("&Remove"), page );
-  grid1->addWidget(m_pRemove,3,1);
+  m_pAdd = new QPushButton( i18n("Add"), this );
+  m_pAdd->setGeometry( 180, 120, 100, 30 );
+  m_pRemove = new QPushButton( i18n("Remove"), this );
+  m_pRemove->setGeometry( 180, 160, 100, 30 );
 
+  m_pRow = new QCheckBox( i18n("Description in Row"), this );
+  m_pRow->setGeometry( 10, 270, 300, 30 );
+  m_pCol = new QCheckBox( i18n("Description in Column"), this );
+  m_pCol->setGeometry( 10, 300, 300, 30 );
+  m_pCopy = new QCheckBox( i18n("Copy data"), this );
+  m_pCopy->setGeometry( 10, 330, 300, 30 );
 
+  connect( m_pOk, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
+  connect( m_pClose, SIGNAL( clicked() ), this, SLOT( slotClose() ) );
   connect( m_pAdd, SIGNAL( clicked() ), this, SLOT( slotAdd() ) );
   connect( m_pRemove, SIGNAL( clicked() ), this, SLOT( slotRemove() ) );
   connect( m_pRef, SIGNAL( returnPressed() ), this, SLOT( slotReturnPressed() ) );
 
-  connect( m_pView, SIGNAL( sig_selectionChanged( KSpreadSheet*, const QRect& ) ),
-	   this, SLOT( slotSelectionChanged( KSpreadSheet*, const QRect& ) ) );
-}
-
-KSpreadConsolidate::~KSpreadConsolidate()
-{
-    kdDebug(36001)<<"KSpreadConsolidate::~KSpreadConsolidate()\n";
+  connect( m_pView, SIGNAL( sig_selectionChanged( KSpreadTable*, const QRect& ) ),
+	   this, SLOT( slotSelectionChanged( KSpreadTable*, const QRect& ) ) );
 }
 
+enum Function { F_SUM, F_AVERAGE };
 enum Description { D_ROW, D_COL, D_NONE, D_BOTH };
 
 struct st_cell
@@ -124,28 +109,15 @@ struct st_cell
 
 void KSpreadConsolidate::slotOk()
 {
-  m_pView->doc()->emitBeginOperation( false );
-
   KSpreadMap *map = m_pView->doc()->map();
 
-  KSpreadSheet* table = m_pView->activeTable();
-  int dx = m_pView->selectionInfo()->selection().left();
-  int dy = m_pView->selectionInfo()->selection().top();
+  KSpreadTable* table = m_pView->activeTable();
+  int dx = m_pView->canvasWidget()->markerColumn();
+  int dy = m_pView->canvasWidget()->markerRow();
 
-  QString function;
-
-  switch( m_pFunction->currentItem() )
-  {
-    case Sum:      function = "SUM"; break;
-    case Average:  function = "AVERAGE"; break;
-    case Count:    function = "COUNT"; break;
-    case Max:      function = "MAX"; break;
-    case Min:      function = "MIN"; break;
-    case Product:  function = "PRODUCT"; break;
-    case StdDev:   function = "STDDEV"; break;
-    case Var:      function = "VARIANCE"; break;
-    default: break; // bad bad !
-  }
+  Function f = F_SUM;
+  if ( m_pFunction->currentItem() == m_idAverage )
+    f = F_AVERAGE;
 
   QStringList r = refs();
   QValueList<KSpreadRange> ranges;
@@ -154,7 +126,7 @@ void KSpreadConsolidate::slotOk()
   {
     KSpreadRange r( *s, map );
     // TODO: Check for valid
-    Q_ASSERT( r.isValid() );
+    ASSERT( r.isValid() );
 
     if ( r.table == 0 )
     {
@@ -175,42 +147,27 @@ void KSpreadConsolidate::slotOk()
     desc = D_NONE;
 
   // Check whether all ranges have same size
-  Q_ASSERT( ranges.count() > 0 );
+  ASSERT( ranges.count() > 0 );
   QValueList<KSpreadRange>::Iterator it = ranges.begin();
   int w = (*it).range.right() - (*it).range.left() + 1;
   int h = (*it).range.bottom() - (*it).range.top() + 1;
   if ( w <= ( ( desc == D_BOTH || desc == D_COL ) ? 1 : 0 ) ||
        h <= ( ( desc == D_BOTH || desc == D_ROW ) ? 1 : 0 ) )
   {
-    m_pView->slotUpdateView( m_pView->activeTable() );
     KMessageBox::error( this, i18n( "The range\n%1\nis too small" ).arg( *( r.begin() ) ));
     return;
   }
 
-  if( (*it).range.bottom()==KS_rowMax || (*it).range.right()== KS_colMax )
-  {
-    m_pView->slotUpdateView( m_pView->activeTable() );
-    KMessageBox::error( this, i18n( "The range\n%1\nis too large" ).arg( *( r.begin() ) ));
-    return;
-  }
-
   ++it;
   int i = 1;
   for( ; it != ranges.end(); ++it, i++ )
   {
     int w2 = (*it).range.right() - (*it).range.left() + 1;
     int h2 = (*it).range.bottom() - (*it).range.top() + 1;
-    if((*it).range.bottom()==KS_rowMax || (*it).range.right()== KS_colMax)
-    {
-      m_pView->slotUpdateView( m_pView->activeTable() );
-      KMessageBox::error( this, i18n( "The range\n%1\nis too large" ).arg( r[i]));
-      return;
-    }
     if ( ( desc == D_NONE && ( w != w2 || h != h2 ) ) ||
 	 ( desc == D_ROW && h != h2 ) ||
 	 ( desc == D_COL && w != w2 ) )
     {
-      m_pView->slotUpdateView( m_pView->activeTable() );
       QString tmp = i18n( "The ranges\n%1\nand\n%2\nhave different size").arg( *( r.begin() ) ).arg( r[i] );
       KMessageBox::error( this, tmp);
       return;
@@ -226,13 +183,12 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
-      Q_ASSERT( t );
+      KSpreadTable *t = (*it).table;
+      assert( t );
       QRect r;
       r.setCoords( (*it).range.left(), (*it).range.top(), (*it).range.right(), (*it).range.bottom() );
       if ( t == table && r.intersects( dest ) )
       {
-        m_pView->slotUpdateView( m_pView->activeTable() );
 	QString tmp( i18n("The source tables intersect with the destination table") );
 	KMessageBox::error( this, tmp);
 	return;
@@ -243,26 +199,55 @@ void KSpreadConsolidate::slotOk()
     {
       for( int y = 0; y < h; y++ )
       {
-        bool novalue=true;
-        QString formula = "=" + function + "(";
+	double dbl = 0.0;
+	QString formel;
+	if ( f == F_AVERAGE )
+	  formel = "=(";
+	else if ( f == F_SUM )
+	  formel = "=";
+	else
+	  assert( 0 );
+
 	it = ranges.begin();
 	for( ; it != ranges.end(); ++it )
         {
-	  KSpreadSheet *t = (*it).table;
+	  // Calculate value directly
+	  KSpreadTable *t = (*it).table;
 	  assert( t );
 	  KSpreadCell *c = t->cellAt( x + (*it).range.left(), y + (*it).range.top() );
-          if(!c->isDefault())
-                novalue=false;
-	  if ( it != ranges.begin() )
-	    formula += ";";
-	  formula += (*it).tableName + "!";
-	  formula += c->name();
+	  if ( c && c->isValue() )
+	  {
+	    if ( f == F_SUM || f == F_AVERAGE )
+	      dbl += c->valueDouble();
+	    else
+	      assert( 0 );
+	  }
+	
+	  // Built formula
+	  if ( f == F_SUM || f == F_AVERAGE )
+	  {
+	    if ( formel.length() > 2 )
+	      formel += "+";
+	    formel += (*it).tableName;
+	    formel += "!";
+	    formel += util_cellName( x + (*it).range.left(), y + (*it).range.top() );
+	  }
+	  else
+	    assert( 0 );
 	}
-	formula += ")";
-
-        if(!novalue)
-	  table->setText( dy + y, dx + x,
-            m_pCopy->isChecked() ? evaluate( formula, table ) : formula );
+	
+	if ( f == F_AVERAGE )
+	{
+	  char buffer[ 100 ];
+	  sprintf( buffer, "%i", h );
+	  formel += ") / ";
+	  formel += buffer;
+	  dbl /= (double)h;
+	}
+	
+	if ( m_pCopy->isChecked() )
+	  formel.sprintf( "%f", dbl );
+	table->setText( dy + y, dx + x, formel );
       }
     }
   }
@@ -273,7 +258,7 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       kdDebug(36001) << "FROM " << (*it).range.left() << " to " << (*it).range.right() << endl;
       for( int x = (*it).range.left(); x <= (*it).range.right() ; ++x )
@@ -281,7 +266,7 @@ void KSpreadConsolidate::slotOk()
 	KSpreadCell *c = t->cellAt( x, (*it).range.top() );
 	if ( c )
 	{
-	  QString s = c->value().asString();
+	  QString s = c->valueString();
 	  if ( !lst.contains( s ) )
 	    lst.append( s );
 	}
@@ -295,13 +280,12 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       QRect r;
       r.setCoords( (*it).range.left(), (*it).range.top(), (*it).range.right(), (*it).range.bottom() );
       if ( t == table && r.intersects( dest ) )
       {
-        m_pView->slotUpdateView( m_pView->activeTable() );
 	QString tmp( i18n("The source tables intersect with the destination table") );
 	KMessageBox::error( this, tmp);
 	return;
@@ -318,33 +302,65 @@ void KSpreadConsolidate::slotOk()
       for( int y = 1; y < h; ++y )
       {
 	int count = 0;
-        QString formula = "=" + function + "(";
+	double dbl = 0.0;
+	QString formel;
+	if ( f == F_AVERAGE )
+	  formel = "=(";
+	else if ( f == F_SUM )
+	  formel = "=";
+	else
+	  assert( 0 );
+
 	it = ranges.begin();
 	for( ; it != ranges.end(); ++it )
         {
 	  for( int i = (*it).range.left(); i <= (*it).range.right(); ++i )
 	  {
-	    KSpreadSheet *t = (*it).table;
+	    KSpreadTable *t = (*it).table;
 	    assert( t );
 	    KSpreadCell *c = t->cellAt( i, (*it).range.top() );
 	    if ( c )
 	    {
-	      if ( c->value().asString() == *s )
+	      if ( c->valueString() == *s )
 	      {
-//		KSpreadCell *c2 = t->cellAt( i, y + (*it).range.top() );
+		KSpreadCell *c2 = t->cellAt( i, y + (*it).range.top() );
 		count++;
-		if ( it != ranges.begin() )
-		  formula += ";";
-		formula += (*it).tableName + "!";
-		formula += KSpreadCell::name( i, y + (*it).range.top() );
+		// Calculate value
+		if ( c2 && c2->isValue() )
+		{
+		  if ( f == F_SUM || f == F_AVERAGE )
+		    dbl += c2->valueDouble();
+		  else
+		    assert( 0 );
+		}
+		// Create formula
+		if ( f == F_SUM || f == F_AVERAGE )
+		{
+		  if ( formel != "=" )
+		    formel += "+";
+		  formel += (*it).tableName;
+		  formel += "!";
+		  formel += util_cellName( i, y + (*it).range.top() );
+		}
+		else
+		  assert( 0 );
 	      }
 	    }
 	  }
 	}
-	formula += ")";
 
-	table->setText( dy + y, dx + x,
-          m_pCopy->isChecked() ? evaluate( formula, table ) : formula );
+	if ( f == F_AVERAGE )
+	{
+	  char buffer[ 100 ];
+	  sprintf( buffer, "%i", count );
+	  formel += ") / ";
+	  formel += buffer;
+	  dbl /= (double)count;
+	}
+
+	if ( m_pCopy->isChecked() )
+	  formel.sprintf( "%f", dbl );	
+	table->setText( dy + y, dx + x, formel );
       }
     }
   }
@@ -355,14 +371,14 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       for( int y = (*it).range.top(); y <= (*it).range.bottom() ; ++y )
       {
 	KSpreadCell *c = t->cellAt( (*it).range.left(), y );
 	if ( c )
 	{
-	  QString s = c->value().asString();
+	  QString s = c->valueString();
 	  if ( !s.isEmpty() && lst.find( s ) == lst.end() )
 	    lst.append( s );
 	}
@@ -376,13 +392,12 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       QRect r;
       r.setCoords( (*it).range.left(), (*it).range.top(), (*it).range.right(), (*it).range.bottom() );
       if ( t == table && r.intersects( dest ) )
       {
-        m_pView->slotUpdateView( m_pView->activeTable() );
 	QString tmp( i18n("The source tables intersect with the destination table") );
 	KMessageBox::error( this, tmp);
 	return;
@@ -399,34 +414,66 @@ void KSpreadConsolidate::slotOk()
       for( int x = 1; x < w; ++x )
       {
 	int count = 0;
-        QString formula = "=" + function + "(";
+	double dbl = 0.0;
+	QString formel;
+	if ( f == F_AVERAGE )
+	  formel = "=(";
+	else if ( f == F_SUM )
+	  formel = "=";
+	else
+	  assert( 0 );
+
 	it = ranges.begin();
 	for( ; it != ranges.end(); ++it )
         {
 	  for( int i = (*it).range.top(); i <= (*it).range.bottom(); i++ )
 	  {
-	    KSpreadSheet *t = (*it).table;
+	    KSpreadTable *t = (*it).table;
 	    assert( t );
 	    KSpreadCell *c = t->cellAt( (*it).range.left(), i );
 	    if ( c )
 	    {
-	      QString v = c->value().asString();
+	      QString v = c->valueString();
 	      if ( !v.isEmpty() && *s == v )
 	      {
-//		KSpreadCell *c2 = t->cellAt( x + (*it).range.left(), i );
+		KSpreadCell *c2 = t->cellAt( x + (*it).range.left(), i );
 		count++;
-		if ( it != ranges.begin() ) formula += ";";
-		formula += (*it).tableName + "!";
-		formula += KSpreadCell::name( i, y + (*it).range.top() );
+		// Calculate value
+		if ( c2 && c2->isValue() )
+		{
+		  if ( f == F_SUM || f == F_AVERAGE )
+		    dbl += c2->valueDouble();
+		  else
+		    assert( 0 );
+		}
+		// Create formula
+		if ( f == F_SUM || f == F_AVERAGE )
+		{
+		  if ( formel != "=" )
+		    formel += "+";
+		  formel += (*it).tableName;
+		  formel += "!";
+		  formel += util_cellName( x + (*it).range.left(), i );
+		}
+		else
+		  assert( 0 );
 	      }
 	    }
 	  }
 	}
 
-	formula += ")";
+	if ( f == F_AVERAGE )
+	{
+	  char buffer[ 100 ];
+	  sprintf( buffer, "%i", count );
+	  formel += ") / ";
+	  formel += buffer;
+	  dbl /= (double)count;
+	}
 
-	table->setText( dy + y, dx + x,
-          m_pCopy->isChecked() ? evaluate( formula, table ) : formula );
+	if ( m_pCopy->isChecked() )
+	  formel.sprintf( "%f", dbl );	
+	table->setText( dy + y, dx + x, formel );
       }
     }
   }
@@ -437,14 +484,14 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       for( int y = (*it).range.top() + 1; y <= (*it).range.bottom() ; ++y )
       {
 	KSpreadCell *c = t->cellAt( (*it).range.left(), y );
 	if ( c )
 	{
-	  QString s = c->value().asString();
+	  QString s = c->valueString();
 	  if ( !s.isEmpty() && cols.find( s ) == cols.end() )
 	    cols.append( s );
 	}
@@ -457,14 +504,14 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       for( int x = (*it).range.left() + 1; x <= (*it).range.right() ; ++x )
       {
 	KSpreadCell *c = t->cellAt( x, (*it).range.top() );
 	if ( c )
 	{
-	  QString s = c->value().asString();
+	  QString s = c->valueString();
 	  if ( !s.isEmpty() && rows.find( s ) == rows.end() )
 	    rows.append( s );
 	}
@@ -478,13 +525,12 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       QRect r;
       r.setCoords( (*it).range.left(), (*it).range.top(), (*it).range.right(), (*it).range.bottom() );
       if ( t == table && r.intersects( dest ) )
       {
-        m_pView->slotUpdateView( m_pView->activeTable() );
 	QString tmp( i18n("The source tables intersect with the destination table") );
 	KMessageBox::error( this, tmp);
 	return;
@@ -496,22 +542,22 @@ void KSpreadConsolidate::slotOk()
     it = ranges.begin();
     for( ; it != ranges.end(); ++it )
     {
-      KSpreadSheet *t = (*it).table;
+      KSpreadTable *t = (*it).table;
       assert( t );
       for( int x = (*it).range.left() + 1; x <= (*it).range.right() ; ++x )
       {
 	KSpreadCell *c = t->cellAt( x, (*it).range.top() );
 	if ( c )
 	{
-	  QString ydesc = c->value().asString();
+	  QString ydesc = c->valueString();
 	  for( int y = (*it).range.top() + 1; y <= (*it).range.bottom() ; ++y )
 	  {
 	    KSpreadCell *c2 = t->cellAt( (*it).range.left(), y );
 	    if ( c2 )
 	    {
-	      QString xdesc = c2->value().asString();
+	      QString xdesc = c2->valueString();
 	      KSpreadCell *c3 = t->cellAt( x, y );
-	      if ( c3 && c3->value().isNumber() )
+	      if ( c3 && c3->isValue() )
 	      {
 		st_cell k;
 		k.xdesc = xdesc;
@@ -550,35 +596,62 @@ void KSpreadConsolidate::slotOk()
       for( ; xdesc != cols.end(); ++xdesc, y++ )
       {
 	int count = 0;
-        QString formula = "=" + function + "(";
+	double dbl = 0.0;
+	QString formel;
+	if ( f == F_AVERAGE )
+	  formel = "=(";
+	else if ( f == F_SUM )
+	  formel = "=";
+	else
+	  assert( 0 );
+	
 	QValueList<st_cell>::Iterator lit = lst.begin();
 	for( ; lit != lst.end(); ++lit )
 	{
 	  if ( (*lit).xdesc == *xdesc && (*lit).ydesc == *ydesc )
 	  {
 	    count++;
-  	    if ( it != ranges.begin() ) formula += ";";
-	    formula += (*it).tableName + "!";
-	    formula += KSpreadCell::name( i, y + (*it).range.top() );
+	    // Calculate value
+	    if ( f == F_SUM || f == F_AVERAGE )
+	      dbl += (*lit).cell->valueDouble();
+	    else
+	      assert( 0 );
+	    // Create formula
+	    if ( f == F_SUM || f == F_AVERAGE )
+	    {
+	      if ( formel != "=" )
+              formel += "+";
+	      formel += (*lit).table;
+	      formel += "!";
+	      formel += util_cellName( (*lit).x, (*lit).y );
+	    }
+	    else
+	      assert( 0 );
 	  }
 	}
-	formula += ")";
+	
+	if ( f == F_AVERAGE )
+	{
+	  char buffer[ 100 ];
+	  sprintf( buffer, "%i", count );
+	  formel += ") / ";
+	  formel += buffer;
+	  dbl /= (double)count;
+	}
 
-	table->setText( dy + y, dx + x,
-          m_pCopy->isChecked() ? evaluate( formula, table ) : formula );
+	if ( m_pCopy->isChecked() )
+	  formel.sprintf( "%f", dbl );	
+	table->setText( dy + y, dx + x, formel );
       }
     }
   }
-  m_pView->updateEditWidget();
-  m_pView->slotUpdateView( m_pView->activeTable() );
+
   accept();
-  delete this;
 }
 
-void KSpreadConsolidate::slotCancel()
+void KSpreadConsolidate::slotClose()
 {
   reject();
-  delete this;
 }
 
 void KSpreadConsolidate::slotAdd()
@@ -595,7 +668,7 @@ void KSpreadConsolidate::slotRemove()
   m_pRefs->removeItem( i );
 
   if ( m_pRefs->count() == 0 )
-    actionButton( Ok )->setEnabled( false );
+    m_pOk->setEnabled( false );
 }
 
 QStringList KSpreadConsolidate::refs()
@@ -609,7 +682,7 @@ QStringList KSpreadConsolidate::refs()
   return list;
 }
 
-void KSpreadConsolidate::slotSelectionChanged( KSpreadSheet* _table, const QRect& _selection )
+void KSpreadConsolidate::slotSelectionChanged( KSpreadTable* _table, const QRect& _selection )
 {
   if ( _selection.left() == 0 || _selection.top() == 0 ||
        _selection.right() == 0 || _selection.bottom() == 0 )
@@ -637,40 +710,8 @@ void KSpreadConsolidate::slotReturnPressed()
   if ( !txt.isEmpty() )
   {
     m_pRefs->insertItem( txt );
-    actionButton( Ok )->setEnabled( true );
+    m_pOk->setEnabled( true );
   }
 }
 
-void KSpreadConsolidate::closeEvent ( QCloseEvent * )
-{
-    delete this;
-}
-
-QString KSpreadConsolidate::evaluate( const QString& formula, KSpreadSheet* table )
-{
-  QString result = "###";
-
-  kdDebug(36001)<<"KSpreadConsolidate::evaluate " << formula << endl;
-
-  KSContext context;
-  QPtrList<KSpreadDependency> lst;
-
-  // parse and evaluate formula
-  KSParseNode* code = table->doc()->interpreter()->parse( context,
-    table, formula, lst );
-  if( !code ) return result;
-
-  context = table->doc()->context();
-  if ( !table->doc()->interpreter()->evaluate( context, code, table, 0 ) )
-    return result;
-
-  if ( context.value()->type() == KSValue::DoubleType )
-     return QString::number( context.value()->doubleValue() );
-
-  if ( context.value()->type() == KSValue::IntType )
-     return QString::number( context.value()->intValue() );
-
-  return result;
-}
-
 #include "kspread_dlg_cons.moc"
