@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 1999,2000,2001 Montel Laurent <lmontel@mandrakesoft.com>
+   Copyright (C) 1999 Montel Laurent <montell@club-internet.fr>
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
@@ -17,38 +17,42 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <qprinter.h>
 
 #include "kspread_dlg_special.h"
+#include "kspread_view.h"
 #include "kspread_canvas.h"
-#include "kspread_sheet.h"
+#include "kspread_doc.h"
+#include "kspread_table.h"
+#include "kspread_global.h"
 
 #include <qlayout.h>
+#include <kapp.h>
 #include <klocale.h>
+#include <kbuttonbox.h>
 #include <qbuttongroup.h>
-#include <qradiobutton.h>
 
 KSpreadspecial::KSpreadspecial( KSpreadView* parent, const char* name )
-	: KDialogBase( parent, name, TRUE,i18n("Special Paste"),Ok|Cancel  )
+	: QDialog( parent, name, TRUE )
 {
     m_pView = parent;
-    QWidget *page = new QWidget( this );
-    setMainWidget(page);
-    QVBoxLayout *lay1 = new QVBoxLayout( page, 0, spacingHint() );
 
-    QButtonGroup *grp = new QButtonGroup( 1, QGroupBox::Horizontal, i18n( "Paste What" ),page );
+    setCaption( i18n("Special Paste") );
+    QVBoxLayout *lay1 = new QVBoxLayout( this );
+    lay1->setMargin( 5 );
+    lay1->setSpacing( 10 );
+
+    QButtonGroup *grp = new QButtonGroup( 1, QGroupBox::Horizontal, i18n( "Paste what:" ),this );
     grp->setRadioButtonExclusive( TRUE );
     grp->layout();
     lay1->addWidget(grp);
     rb1 = new QRadioButton( i18n("Everything"), grp );
     rb2 = new QRadioButton( i18n("Text"), grp );
     rb3 = new QRadioButton( i18n("Format"), grp );
-    rb10 = new QRadioButton( i18n("Comment"), grp );
-    rb11 = new QRadioButton( i18n("Result"), grp );
-
     rb4 = new QRadioButton( i18n("Everything without border"), grp );
     rb1->setChecked(true);
 
-    grp = new QButtonGroup( 1, QGroupBox::Horizontal, i18n("Operation"),page);
+    grp = new QButtonGroup( 1, QGroupBox::Horizontal, i18n("Operation"),this);
     grp->setRadioButtonExclusive( TRUE );
     grp->layout();
     lay1->addWidget(grp);
@@ -56,7 +60,7 @@ KSpreadspecial::KSpreadspecial( KSpreadView* parent, const char* name )
 
     rb5 = new QRadioButton( i18n("Overwrite"), grp );
     rb6 = new QRadioButton( i18n("Addition"), grp );
-    rb7 = new QRadioButton( i18n("Subtraction"), grp );
+    rb7 = new QRadioButton( i18n("Substraction"), grp );
     rb8 = new QRadioButton( i18n("Multiplication"), grp );
     rb9 = new QRadioButton( i18n("Division"), grp );
     rb5->setChecked(true);
@@ -65,9 +69,17 @@ KSpreadspecial::KSpreadspecial( KSpreadView* parent, const char* name )
     // cb->layout();
     // lay1->addWidget(cb);
 
-    connect( this, SIGNAL( okClicked() ), this, SLOT( slotOk() ) );
+    KButtonBox *bb = new KButtonBox( this );
+    bb->addStretch();
+    m_pOk = bb->addButton( i18n("OK") );
+    m_pOk->setDefault( TRUE );
+    m_pClose = bb->addButton( i18n( "Close" ) );
+    bb->layout();
+    lay1->addWidget( bb );
+
+    connect( m_pOk, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
+    connect( m_pClose, SIGNAL( clicked() ), this, SLOT( slotClose() ) );
     connect( rb3, SIGNAL( toggled( bool ) ), this, SLOT( slotToggled( bool ) ) );
-    connect( rb10, SIGNAL( toggled( bool ) ), this, SLOT( slotToggled( bool ) ) );
 }
 
 void KSpreadspecial::slotOk()
@@ -92,10 +104,6 @@ void KSpreadspecial::slotOk()
 	sp = Format;
     else if( rb4->isChecked() )
 	sp = NoBorder;
-    else if( rb10->isChecked() )
-	sp = Comment;
-    else if( rb11->isChecked() )
-	sp = Result;
 
     if( rb5->isChecked() )
 	op = OverWrite;
@@ -108,12 +116,16 @@ void KSpreadspecial::slotOk()
     if( rb9->isChecked() )
 	op = Div;
 
-    m_pView->doc()->emitBeginOperation( false );
-    m_pView->activeTable()->paste( m_pView->selection(), true, sp, op );
-    m_pView->slotUpdateView( m_pView->activeTable() );
+    m_pView->activeTable()->paste( QPoint(  m_pView->canvasWidget()->markerColumn(),
+					    m_pView->canvasWidget()->markerRow() ), sp, op );
     accept();
 }
 
+void KSpreadspecial::slotClose()
+{
+    reject();
+}
+
 void KSpreadspecial::slotToggled( bool b )
 {
     rb5->setEnabled( !b );
