@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 1999, 2000, 2001, 2002  Montel Laurent <lmontel@mandrakesoft.com>
+   Copyright (C) 1999 Montel Laurent <montell@club-internet.fr>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,13 +21,17 @@
 #ifndef __kspread_dlg_special__
 #define __kspread_dlg_special__
 
-#include <kdialogbase.h>
+#include <qdialog.h>
+#include <qpushbutton.h>
+#include <qradiobutton.h>
+// #include <qcheckbox.h>
+
 
 class KSpreadView;
-class KSpreadSheet;
+class KSpreadTable;
 class KSpreadCell;
-class QRadioButton;
-class KSpreadspecial : public KDialogBase
+
+class KSpreadspecial : public QDialog
 {
     Q_OBJECT
 public:
@@ -35,13 +39,24 @@ public:
 
 public slots:
     void slotOk();
+    void slotClose();
     void slotToggled( bool );
-
-private:
+    
+protected:
     KSpreadView* m_pView;
-    QRadioButton *rb1, *rb2, *rb3, *rb4, *rb5;
-    QRadioButton *rb6, *rb7, *rb8;
-    QRadioButton *rb9, *rb10, *rb11;
+
+    QPushButton* m_pOk;
+    QPushButton* m_pClose;
+    QRadioButton *rb1;
+    QRadioButton *rb2;
+    QRadioButton *rb3;
+    QRadioButton *rb4;
+    QRadioButton *rb5;
+    QRadioButton *rb6;
+    QRadioButton *rb7;
+    QRadioButton *rb8;
+    QRadioButton *rb9;
+    // QCheckBox *cb;
 };
 
 #endif
