@@ -24,13 +24,14 @@
 #include <qpainter.h>
 #include <qstrlist.h>
 
+class KSpreadTableName;
 
 /**
  * This tab bar is used by @ref KSpreadView. It is used to choose between all
  * available tables.
  *
  * Adding, removing or renaming of tabs does not automatically add, rename or
- * remove KSpreadSheet objects. The tabbar is just a GUI element.
+ * remove KSpreadTable objects. The tabbar is just a GUI element.
  *
  * But activating a tab emits a signal which in turn will show this table
  * in the associated KSpreadView.
@@ -42,7 +43,6 @@ class KSpreadTabBar : public QWidget
     Q_OBJECT
 public:
     KSpreadTabBar( KSpreadView *_parent );
-    virtual ~KSpreadTabBar();
 
     /**
      * Adds a tab to the bar and paints it. The tab does not become active.
@@ -55,7 +55,6 @@ public:
      * @see KSpreadView::setActiveTable
      */
     void addHiddenTab( const QString & text );
-    void removeHiddenTab(const QString & text);
     /**
      * Removes the tab from the bar. If the tab was the active one then the one
      * left of it ( or if not available ) the one right of it will become active.
@@ -67,11 +66,9 @@ public:
      * Renames a tab.
      */
     void renameTab( const QString& old_name, const QString& new_name );
-
-    void rename( KSpreadSheet * table, QString name, QString const & activeName, bool ok );
-
+    
     /**
-     * Moves the tab with number _from befor tab number _to if @param _before is
+     * Moves the tab with number _from befor tab number _to if @param _before is 
      * true _from is inserted before _to. If false it is inserted after.
      */
     void moveTab( int _from, int _to, bool _before = true );
@@ -81,10 +78,6 @@ public:
      */
     void removeAllTabs();
 
-    bool canScrollLeft() const;
-
-    bool canScrollRight() const;
-
     void scrollLeft();
     void scrollRight();
     void scrollFirst();
@@ -105,9 +98,7 @@ public:
     * and highlights first name in tabList
     */
     void hideTable();
-    void hideTable(const QString& tableName );
-
-
+    
     /**
      * Shows the table. This makes only sense if
      * the table was hiddem before.
@@ -115,19 +106,16 @@ public:
      * The table does not become automatically the active one.
      */
     void showTable(const QString& _text);
-    void showTable(QStringList list);
-    void displayTable(const QString& _text);
-
+    
     /**
      * @return the name of all visible tables.
      */
-    QStringList listshow()const{return  tabsList;}
+    QStringList listshow(){return  tabsList;}
     /**
      * @return the name of all hidden tables.
      */
-    QStringList listhide()const{return  tablehide;}
-
-
+    QStringList listhide(){return  tablehide;}
+    
 signals:
     /**
      * Emitted if the active tab changed. This will cause the
@@ -135,13 +123,12 @@ signals:
      */
     void tabChanged( const QString& _text );
 
-public slots:
-    void slotRename( );
-
-protected slots:
+protected slots:    
     /**
      * Opens a dialog to rename active tab.
      */
+    void slotRename( );
+    void slotRemove( );
     void slotAdd();
     void slotAutoScroll( );
 
@@ -160,6 +147,11 @@ protected:
 
     enum { autoScrollNo = 0, autoScrollLeft, autoScrollRight };
     enum { moveTabNo = 0, moveTabBefore, moveTabAfter };
+    /**
+     * Pointer to the last popup menu.
+     * If this pointer is not 0L delete before usage.
+     */
+    QPopupMenu *m_pPopupMenu;
 
     /**
      * List with the names of all tabs. The order in this list determines the
@@ -202,11 +194,11 @@ protected:
      * If no tab is being moved this value is 0.
      */
     int m_moveTab;
-
+	
     /**
      * Indicates whether a tab is being moved using the mouse and in which
      * direction.
-     */
+     */ 	
     int m_moveTabFlag;
 
     /**
