@@ -1,5 +1,5 @@
 /*
-    $Id: stats.cpp 466447 2005-10-02 17:54:10Z zander $
+    $Id: stats.cpp,v 1.1.1.1 1999/10/20 10:10:32 kulow Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -19,8 +19,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
 
