@@ -17,26 +17,38 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include "kword_doc.h"
+#include "kword_shell.h"
+
 #include <koApplication.h>
+#include <kaboutdata.h>
 #include <kcmdlineargs.h>
-#include <dcopclient.h>
-#include "kwaboutdata.h"
+#include <klocale.h>
+#include "kword_factory.h"
+
 
 static const KCmdLineOptions options[]=
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
+	{"+[file]", I18N_NOOP("File To Open"),0},
+	{0,0,0}
 };
 
-extern "C" KWORD_EXPORT int kdemain( int argc, char **argv )
+extern "C"
 {
-    KCmdLineArgs::init( argc, argv, newKWordAboutData());
+    void* init_libkword();
+}
+
+int main( int argc, char **argv )
+{
+    KCmdLineArgs::init( argc, argv, KWordFactory::aboutData());
     KCmdLineArgs::addCmdLineOptions( options );
 
     KoApplication app;
 
-    if (!app.start())
-	return 1;
+    init_libkword();
+
+    app.start();
+
     app.exec();
 
     return 0;
