@@ -20,39 +20,32 @@
 #ifndef __ko_query_trader_h__
 #define __ko_query_trader_h__
 
+#include <qstring.h>
 #include <kservice.h>
-#include <ksharedptr.h>
+#include <qstringlist.h>
 #include <qvaluelist.h>
-#include <koffice_export.h>
 
-class QObject;
-class QStringList;
 class KoDocument;
 class KoFilter;
-class KoFilterChain;
+class KoFilterDialog;
 
 /**
- *  Represents an available KOffice component
+ *  Represents an available koffice component
  *  that supports the document interface.
  */
-class KOFFICECORE_EXPORT KoDocumentEntry
+class KoDocumentEntry
 {
 
 public:
+
   KoDocumentEntry() { m_service = 0L; } // for QValueList
-  KoDocumentEntry( KService::Ptr service );
+  KoDocumentEntry( KService::Ptr _service );
   ~KoDocumentEntry() { }
 
   KService::Ptr service() const { return m_service; }
 
-  /**
-   * @return TRUE if the service pointer is null
-   */
   bool isEmpty() const { return m_service == 0L; }
 
-  /**
-   * @return name of the associated service
-   */
   QString name() const { return m_service->name(); }
 
   /**
@@ -67,39 +60,19 @@ public:
   { return mimeTypes().contains( _mimetype ); }
 
   /**
-   *  Uses the factory of the component to create
-   *  a document. If that is not possible, 0 is returned.
+   *  Uses the factory of the component  to create
+   *  a document. If that is not possible 0 is returned.
    */
-  KoDocument* createDoc( KoDocument* parent = 0, const char* name = 0 ) const;
+  KoDocument* createDoc( KoDocument* parent = 0, const char* name = 0 );
 
   /**
-   *  This function will query ksycoca to find all available components.
-   *  The result will only contain parts, which are embeddable into a document
+   *  This function will query KDED to find all available components.
    *
-   *  @param _constr is a constraint expression as used by KTrader.
-   *                 You can use it to set additional restrictions on the available
-   *                 components.
-   */
-  static QValueList<KoDocumentEntry> query( const QString &  _constr = QString::null );
-
-  /**
-   *  This function will query KDED to find all available filters.
-   *
-   *  @param _onlyDocEmb specifies if only KOffice Parts should be listed which are
-   *                 embeddable into other koDocuments, or all (if false)
-   *                 (eg.: it makes no sense to embed Kexi into KWord,
-   *                 but it makes sense to embed it into KoShell)
    *  @param _constr is a constraint expression as used by KDEDs trader interface.
    *                 You can use it to set additional restrictions on the available
    *                 components.
    */
-  // ### TODO: MERGE WITH ABOVE METHODE WHEN BIC+SIC CHANGES ARE ALLOWED
-  static QValueList<KoDocumentEntry> query( bool _onlyDocEmb,const QString& _constr);
-  /* this is how the signature should be looking after merging
-  static QValueList<KoDocumentEntry> query( bool _onlyDocEmb =true, const QString& _constr = QString::null );
-  or better: use an enum for the first arg.
-  */
-
+  static QValueList<KoDocumentEntry> query( const QString &  _constr = QString::null );
 
   /**
    *  This is only a convenience function.
@@ -116,49 +89,53 @@ private:
 /**
  *  Represents an available filter.
  */
-class KoFilterEntry : public KShared
+class KoFilterEntry
 {
 
 public:
-  typedef KSharedPtr<KoFilterEntry> Ptr;
 
-  KoFilterEntry() : weight( 0 ) { m_service = 0L; } // for QValueList
+  KoFilterEntry() { m_service = 0L; } // for QValueList
   KoFilterEntry( KService::Ptr service );
   ~KoFilterEntry() { }
 
-  KoFilter* createFilter( KoFilterChain* chain, QObject* parent = 0, const char* name = 0 );
+  KoFilter* createFilter( QObject* parent = 0, const char* name = 0);
 
   /**
-   *  The imported mimetype(s).
+   *  The imported mimetype.
    */
-  QStringList import;
+  QString import;
 
   /**
-   *  The exported mimetype(s).
+   *  Comment regarding the imported data format.
    */
-  QStringList export_;
+  QString importDescription;
 
   /**
-   *  The "weight" of this filter path. Has to be > 0 to be valid.
+   *    The exported mimetype.
    */
-  unsigned int weight;
+  QString export_;
 
   /**
-   *  Do we have to check during runtime?
+   *  Comment regarding the exported data format.
    */
-  QString available;
+  QString exportDescription;
 
   /**
-   *  @return TRUE if the filter can import the requested mimetype.
+   *  Which one of the filter methods is implemented?
    */
-  bool imports( const QString& _mimetype ) const
-  { return ( import.contains( _mimetype ) ); }
+  QString implemented;
 
   /**
-   *  @return TRUE if the filter can export the requested mimetype.
+   *  @return TRUE if the filter can imports the requested mimetype.
    */
-  bool exports( const QString& _m ) const
-  { return ( export_.contains( _m ) ); }
+  bool imports( const QString & _mimetype ) const
+  { return ( import.find( _mimetype ) != -1 ); }
+
+  /**
+   *  @return TRUE if the filter can exports the requested mimetype.
+   */
+  bool exports( const QString & _m ) const
+  { return ( export_.find( _m ) != -1 ); }
 
   /**
    *  This function will query KDED to find all available filters.
@@ -167,12 +144,79 @@ public:
    *                 You can use it to set additional restrictions on the available
    *                 components.
    */
-  static QValueList<KoFilterEntry::Ptr> query( const QString& _constr = QString::null );
-
-  KService::Ptr service() const { return m_service; }
+  static QValueList<KoFilterEntry> query( const QString & _constr = QString::null );
 
 private:
   KService::Ptr m_service;
 };
 
+/**
+ *  Represents an available filter dialog.
+ */
+class KoFilterDialogEntry
+{
+
+public:
+
+  KoFilterDialogEntry() { m_service = 0L; }
+  KoFilterDialogEntry( KService::Ptr service );
+  ~KoFilterDialogEntry() { }
+
+  KoFilterDialog* createFilterDialog( QObject* parent = 0, const char* name = 0);
+
+  /**
+   *  The imported mimetype of the matching filter.
+   */
+  QString import;
+
+  /**
+   *  Comment regarding the imported data format of the matching filter.
+   */
+  QString importDescription;
+
+  /**
+   *    The exported mimetype of the matching filter.
+   */
+  QString export_;
+
+  /**
+   *  Comment regarding the exported data format of the matching filter.
+   */
+  QString exportDescription;
+
+  /**
+   *  This function will query KDED to find all available filter dialogs.
+   *
+   *  @param _constr is a constraint expression as used by KDEDs trader interface.
+   *                 You can use it to set additional restrictions on the available
+   *                 components.
+   */
+  static QValueList<KoFilterDialogEntry> query( const QString & _constr = QString::null );
+
+private:
+  KService::Ptr m_service;
+};
+
+/**
+ * Torben says: DONT USE. Use KoDataToolInfo instead!
+class KoToolEntry
+{
+public:
+  KoToolEntry() { };
+  KoToolEntry( const KoComponentEntry& _entry );
+  KoToolEntry( const KoToolEntry& entry );
+
+  QStringList mimeTypes;
+  QStringList commands;
+  QStringList commandsI18N;
+
+  bool supports( const QString &_mime_type ) const { return ( mimeTypes.find( _mime_type ) != mimeTypes.end() ); }
+
+  static QValueList<KoToolEntry> query( const QString &_mime_type );
+
+private:
+  KService::Ptr m_service;
+};
+*/
+
 #endif
