@@ -13,24 +13,39 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #ifndef __main_h__
 #define __main_h__
 
+class KSpell;
+
 #include <qobject.h>
-#include <kdatatool.h>
+
+#include <koDataTool.h>
+
 #include <klibloader.h>
 
-class SpellChecker : public KDataTool
+class SpellChecker : public KoDataTool
 {
     Q_OBJECT
-
 public:
-    SpellChecker( QObject* parent, const char* name, const QStringList & );
-    virtual bool run( const QString& command, void* data, const QString& datatype, const QString& mimetype);
+    SpellChecker( QObject* parent = 0, const char* name = 0 );
+
+    virtual bool run( const QString& command, void* data, const QString& datatype, const QString& mimetype );
+};
+
+class SpellCheckerFactory : public KLibFactory
+{
+    Q_OBJECT
+public:
+    SpellCheckerFactory( QObject* parent = 0, const char* name = 0 );
+    ~SpellCheckerFactory();
+
+    virtual QObject* create( QObject* parent = 0, const char* name = 0, 
+			     const char* classname = "QObject", const QStringList &args = QStringList() );
 };
 
 #endif
